const lightCodeTheme = require("prism-react-renderer/themes/github");
const darkCodeTheme = require("prism-react-renderer/themes/dracula");

/** @type {import('@docusaurus/types').DocusaurusConfig} */
module.exports = {
  title: "Simplifiez-vous le code !",
  tagline: "Améliorez la coopération de vos équipes autour du code source, sans gérer votre forge logicielle !",
  url: process.env.DOCUSAURUS_URL || "https://froggit.fr",
  baseUrl: process.env.DOCUSAURUS_BASEURL || "/",
  onBrokenLinks: "throw",
  onBrokenMarkdownLinks: "warn",
  favicon: "img/favicon/favicon.ico",
  organizationName: "froggit/www", // Usually your GitHub org/user name.
  projectName: "froggit.fr", // Usually your repo name.
  themeConfig: {
    navbar: {
      title: "",
      logo: {
        alt: "Froggit Logo",
        src: "img/logo_typo_froggit.png",
      },
      items: [      
        {label: "✨ Fonctionnalités", position: "left", to: "/#features", exact: true},
        {label: "❓ FAQ", position: "left", to: "/faq"},
        {label: "💰 Tarifs", position: "left", to: "/tarifs"},
        {label: "📔 Doc", position: "left", type: "doc", docId: "intro"},
        {
          label: "🎁 Antisèche git",
          position: "left",
          href: "https://lydra.systeme.io/froggit-inscription",
        },
        {
          label: "👤 Connexion",
          position: "right",
          href: "https://lab.frogg.it/users/sign_in",
        },
        {label: "🚀 S'enregistrer", position: "right", to: "/tarifs"},
      ],
    },
    footer: {
      style: "dark",
      links: [
        {
          title: "Suivez-nous",
          items: [
            {
              label: "▶️ Youtube",
              href: "https://www.youtube.com/channel/UCauIDghddUNu6Fto1nR9Bmg/?sub_confirmation=1",
            },
            {
              label: "👔 Linkedin",
              href: "https://www.linkedin.com/company/froggit",
            },
            {
              label: "🐸 Froggit",
              href: "https://lab.frogg.it/froggit",
            },
            {
              label: "🦊 GitLab",
              href: "https://gitlab.com/froggit",
            },
            {
              label: "🐦 Twitter",
              href: "https://twitter.com/art_devops",
            },
          ],
        },
          
        {
          title: "Pourquoi Froggit ?",
          items: [
            {
              label: "🔐 Ton code source est-il en sécurité?",
              href: "https://lydra.fr/es-2-ton-code-source-est-il-vraiment-en-securite/",
            },
            {
              label: "⚖️ La souveraineté numérique",
              href: "https://lydra.fr/category/souverainete-numerique/",
            },
            {
              label: "❓ git kesako",
              href: "https://github.com/git-guides/",
            },
          ],
        },
        {
          title: "Support",
          items: [
            {
              label: "🛎️ Contact",
              to: "/contacts",
            },
            {
              label: "✔️ Status",
              href: "https://status.froggit.fr",
            },
          ],
        },     
        {
          title: "Société",
          items: [
            {
              label: "🏢 À propos",
              href: "https://lydra.fr",
            },
            {
              label: "💼 Équipe",
              href: "https://lydra.fr/#team",
            },
            {
              label: "⚖️ Mentions légales",
              to: "/mentions_legales",
            },
            {
              label: "📜 CGV",
              to: "/CGV",
            },
            {
              label: "📃 CGU",
              to: "/CGU",
            },
            {
              label: "🔍 Politique de confidentialité",
              to: "/confidentialite",
            },
            {
              label: "👥 Sous-traitants",
              to: "/sous-traitants",
            },
          ],
        },
      ],
      
      // eslint-disable-next-line quotes
      copyright: `Lydra © ${new Date().getFullYear()}` +"<br/>"+ `Froggit est fièrement fabriqué avec ❤️ par <a href="http://lydra.fr/">Lydra</a> avec des Logiciels Libres et hébergé en 🇫🇷 chez <a href="https://www.scaleway.fr/">Scaleway</a>` +"<br/>"+ `Construit avec <a href="https://docusaurus.io/fr">Docusaurus</a>`,
    },
    prism: {
      theme: lightCodeTheme,
      darkTheme: darkCodeTheme,
    },
  },
  presets: [
    [
      "@docusaurus/preset-classic",
      {
        docs: {
          sidebarPath: require.resolve("./sidebars.js"),
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master",
        },
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master/blog/",
        },
        theme: {
          customCss: require.resolve("./src/css/custom.css"),
        },
      },
    ],
  ],
};
